@@ -1,12 +1,14 @@
 """Graph creation functions."""
 
 import bz2
-import networkx as nx
 import os
 import xml.sax
 from itertools import groupby
+
+import networkx as nx
 from shapely.geometry import MultiPolygon
 from shapely.geometry import Polygon
+
 from . import boundaries
 from . import distance
 from . import downloader
@@ -35,7 +37,7 @@ def graph_from_bbox(
     memory=None,
     max_query_area_size=50 * 1000 * 50 * 1000,
     clean_periphery=True,
-    infrastructure='way["highway"]',
+    infrastructure=None,
     custom_filter=None,
     custom_settings=None,
 ):
@@ -73,11 +75,10 @@ def graph_from_bbox(
         if True (and simplify=True), buffer 0.5km to get a graph larger than
         requested, then simplify, then truncate it to requested spatial extent
     infrastructure : string
-        download infrastructure of given type. the default is streets
-        (ie, 'way["highway"]') but other infrastructures may be selected like
-        power grids (ie, 'way["power"~"line"]').
+        deprecated, use custom_filter instead
     custom_filter : string
-        a custom network filter to be used instead of the network_type presets
+        a custom network filter to be used instead of the network_type presets,
+        e.g., '["power"~"line"]' or '["highway"~"motorway|trunk"]'
     custom_settings : string
         custom settings to be used in overpass query instead of the defaults
 
@@ -191,7 +192,7 @@ def graph_from_point(
     memory=None,
     max_query_area_size=50 * 1000 * 50 * 1000,
     clean_periphery=True,
-    infrastructure='way["highway"]',
+    infrastructure=None,
     custom_filter=None,
     custom_settings=None,
 ):
@@ -230,11 +231,10 @@ def graph_from_point(
         if True (and simplify=True), buffer 0.5km to get a graph larger than
         requested, then simplify, then truncate it to requested spatial extent
     infrastructure : string
-        download infrastructure of given type. the default is streets
-        (ie, 'way["highway"]') but other infrastructures may be selected like
-        power grids (ie, 'way["power"~"line"]').
+        deprecated, use custom_filter instead
     custom_filter : string
-        a custom network filter to be used instead of the network_type presets
+        a custom network filter to be used instead of the network_type presets,
+        e.g., '["power"~"line"]' or '["highway"~"motorway|trunk"]'
     custom_settings : string
         custom settings to be used in overpass query instead of the defaults
 
@@ -292,7 +292,7 @@ def graph_from_address(
     memory=None,
     max_query_area_size=50 * 1000 * 50 * 1000,
     clean_periphery=True,
-    infrastructure='way["highway"]',
+    infrastructure=None,
     custom_filter=None,
     custom_settings=None,
 ):
@@ -335,11 +335,10 @@ def graph_from_address(
         if True (and simplify=True), buffer 0.5km to get a graph larger than
         requested, then simplify, then truncate it to requested spatial extent
     infrastructure : string
-        download infrastructure of given type. the default is streets
-        (ie, 'way["highway"]') but other infrastructures may be selected like
-        power grids (ie, 'way["power"~"line"]').
+        deprecated, use custom_filter instead
     custom_filter : string
-        a custom network filter to be used instead of the network_type presets
+        a custom network filter to be used instead of the network_type presets,
+        e.g., '["power"~"line"]' or '["highway"~"motorway|trunk"]'
     custom_settings : string
         custom settings to be used in overpass query instead of the defaults
 
@@ -385,7 +384,7 @@ def graph_from_polygon(
     memory=None,
     max_query_area_size=50 * 1000 * 50 * 1000,
     clean_periphery=True,
-    infrastructure='way["highway"]',
+    infrastructure=None,
     custom_filter=None,
     custom_settings=None,
 ):
@@ -418,11 +417,10 @@ def graph_from_polygon(
         if True (and simplify=True), buffer 0.5km to get a graph larger than
         requested, then simplify, then truncate it to requested spatial extent
     infrastructure : string
-        download infrastructure of given type (default is streets
-        (ie, 'way["highway"]') but other infrastructures may be selected
-        like power grids (ie, 'way["power"~"line"]'))
+        deprecated, use custom_filter instead
     custom_filter : string
-        a custom network filter to be used instead of the network_type presets
+        a custom network filter to be used instead of the network_type presets,
+        e.g., '["power"~"line"]' or '["highway"~"motorway|trunk"]'
     custom_settings : string
         custom settings to be used in overpass query instead of the defaults
 
@@ -539,7 +537,7 @@ def graph_from_place(
     memory=None,
     max_query_area_size=50 * 1000 * 50 * 1000,
     clean_periphery=True,
-    infrastructure='way["highway"]',
+    infrastructure=None,
     custom_filter=None,
     custom_settings=None,
 ):
@@ -585,11 +583,10 @@ def graph_from_place(
         if True (and simplify=True), buffer 0.5km to get a graph larger than
         requested, then simplify, then truncate it to requested spatial extent
     infrastructure : string
-        download infrastructure of given type. the default is streets
-        (ie, 'way["highway"]') but other infrastructures may be selected like
-        power grids (ie, 'way["power"~"line"]').
+        deprecated, use custom_filter instead
     custom_filter : string
-        a custom network filter to be used instead of the network_type presets
+        a custom network filter to be used instead of the network_type presets,
+        e.g., '["power"~"line"]' or '["highway"~"motorway|trunk"]'
     custom_settings : string
         custom settings to be used in overpass query instead of the defaults
     Returns
@@ -597,7 +594,7 @@ def graph_from_place(
     G : networkx.MultiDiGraph
     """
     # create a GeoDataFrame with the spatial boundaries of the place(s)
-    if isinstance(query, str) or isinstance(query, dict):
+    if isinstance(query, (str, dict)):
         # if it is a string (place name) or dict (structured place query), then
         # it is a single place
         gdf_place = boundaries.gdf_from_place(
@@ -607,7 +604,7 @@ def graph_from_place(
         # if it is a list, it contains multiple places to get
         gdf_place = boundaries.gdf_from_places(query, buffer_dist=buffer_dist)
     else:
-        raise TypeError("query must be a string or a list of query strings")
+        raise TypeError("query must be dict, string, or list of strings")
 
     # extract the geometry from the GeoDataFrame to use in API query
     polygon = gdf_place["geometry"].unary_union
@@ -633,38 +630,6 @@ def graph_from_place(
     return G
 
 
-def graph_from_file(filepath, bidirectional=False, simplify=True, retain_all=False):
-    """
-    Pass-through function just calls graph_from_xml.
-
-    Deprecated, will be removed in future release.
-
-    Parameters
-    ----------
-    filepath : string
-        path to file containing OSM XML data
-    bidirectional : bool
-        if True, create bidirectional edges for one-way streets
-    simplify : bool
-        if True, simplify the graph topology
-    retain_all : bool
-        if True, return the entire graph even if it is not connected
-
-    Returns
-    -------
-    networkx.MultiDiGraph
-    """
-    from warnings import warn
-
-    msg = (
-        "The `graph_from_file` function has been deprecated and will be "
-        "removed in the next release. Use the new `graph_from_xml` "
-        "function instead."
-    )
-    warn(msg)
-    return graph_from_xml(filepath, bidirectional, simplify, retain_all)
-
-
 def graph_from_xml(filepath, bidirectional=False, simplify=True, retain_all=False):
     """
     Create a graph from data in an OSM-formatted XML file.
@@ -694,7 +659,7 @@ def graph_from_xml(filepath, bidirectional=False, simplify=True, retain_all=Fals
     if simplify:
         G = simplification.simplify_graph(G)
 
-    utils.log(f"graph_from_file returned graph with {len(G)} nodes and {len(G.edges())} edges")
+    utils.log(f"graph_from_xml returned graph with {len(G)} nodes and {len(G.edges())} edges")
     return G
 
 
