@@ -1,13 +1,15 @@
 """Graph utility functions."""
 
+from collections import Counter
+from itertools import chain
+
 import geopandas as gpd
 import networkx as nx
 import numpy as np
 import pandas as pd
-from collections import Counter
-from itertools import chain
 from shapely.geometry import LineString
 from shapely.geometry import Point
+
 from . import distance
 from . import utils
 
@@ -90,34 +92,6 @@ def graph_to_gdfs(G, nodes=True, edges=True, node_geometry=True, fill_edge_geome
         return to_return[0]
 
 
-def gdfs_to_graph(gdf_nodes, gdf_edges):
-    """
-    Pass-through function just calls graph_from_gdfs.
-
-    Deprecated, will be removed in future release.
-
-    Parameters
-    ----------
-    gdf_nodes : geopandas.GeoDataFrame
-        GeoDataFrame of graph nodes
-    gdf_edges : geopandas.GeoDataFrame
-        GeoDataFrame of graph edges
-
-    Returns
-    -------
-    networkx.MultiDiGraph
-    """
-    from warnings import warn
-
-    msg = (
-        "The `gdfs_to_graph` function has been deprecated and will be "
-        "removed in the next release. Use the new `graph_from_gdfs` "
-        "function instead."
-    )
-    warn(msg)
-    return graph_from_gdfs(gdf_nodes, gdf_edges)
-
-
 def graph_from_gdfs(gdf_nodes, gdf_edges):
     """
     Convert node and edge GeoDataFrames into a MultiDiGraph.
